@@ -554,9 +554,10 @@ eel_background_pre_draw (EelBackground *background, int entire_width, int entire
 
 void
 eel_background_draw (EelBackground *background,
-			  GdkDrawable *drawable, GdkGC *gc,
-			  int drawable_x, int drawable_y,
-			  int drawable_width, int drawable_height)
+		     GdkDrawable *drawable, GdkGC *gc,
+		     int src_x, int src_y,
+		     int dest_x, int dest_y,
+		     int dest_width, int dest_height)
 {
 	int x, y;
 	int x_canvas, y_canvas;
@@ -579,22 +580,22 @@ eel_background_draw (EelBackground *background,
 
 	/* x & y are relative to the drawable
 	 */
-	for (y = 0; y < drawable_height; y += PIXBUF_HEIGHT) {
-		for (x = 0; x < drawable_width; x += PIXBUF_WIDTH) {
+	for (y = 0; y < dest_height; y += PIXBUF_HEIGHT) {
+		for (x = 0; x < dest_width; x += PIXBUF_WIDTH) {
 
-			width = MIN (drawable_width - x, PIXBUF_WIDTH);
-			height = MIN (drawable_height - y, PIXBUF_HEIGHT);
+			width = MIN (dest_width - x, PIXBUF_WIDTH);
+			height = MIN (dest_height - y, PIXBUF_HEIGHT);
 
-			x_canvas = drawable_x + x;
-			y_canvas = drawable_y + y;
+			x_canvas = src_x + x;
+			y_canvas = src_y + y;
 
 			canvas_buf_from_pixbuf (&buffer, pixbuf, x_canvas, y_canvas, width, height);
 			eel_background_draw_aa (background, &buffer);
 			gdk_pixbuf_render_to_drawable (pixbuf, drawable, gc,
 						       0, 0,
-						       x, y,
+						       dest_x + x, dest_y + y,
 						       width, height,
-						       GDK_RGB_DITHER_MAX, x_canvas, y_canvas);
+						       GDK_RGB_DITHER_MAX, dest_x + x, dest_y + y);
 		}
 	}
 	
@@ -609,7 +610,10 @@ eel_background_draw_to_drawable (EelBackground *background,
 				      int entire_width, int entire_height)
 {
 	eel_background_pre_draw (background, entire_width, entire_height);
-	eel_background_draw (background, drawable, gc, drawable_x, drawable_y, drawable_width, drawable_height);
+	eel_background_draw (background, drawable, gc,
+			     drawable_x, drawable_y,
+			     drawable_x, drawable_y,
+			     drawable_width, drawable_height);
 }
 
 void
@@ -1003,7 +1007,16 @@ eel_background_draw_flat_box (GtkStyle *style,
 
 	eel_gdk_window_update_sizes (window, &width, &height);	
 
-	eel_background_draw_to_drawable (background, window, gc, 0, 0, width, height, widget->allocation.width, widget->allocation.height);
+	if (area)
+		eel_background_draw_to_drawable (background, window, gc,
+						 area->x, area->y,
+						 area->width, area->height,
+						 widget->allocation.width, widget->allocation.height);
+	else
+		eel_background_draw_to_drawable (background, window, gc,
+						 0, 0,
+						 width, height,
+						 widget->allocation.width, widget->allocation.height);
 	if (area)
 		gdk_gc_set_clip_rectangle (gc, NULL);
 }
